# (ovitters) disable --no-undefined as per upstream advice
#   https://bugzilla.gnome.org/show_bug.cgi?id=732177#c4
#
#   The problem isn't -Wl,--as-needed, it's -Wl,--no-undefined. You aren't going to
#   be able to build libnm-wwan.la with that flag, because it depends on symbols in
#   the NM binary. (libnm-wwan is a library which is shared between the wwan and bt
#   modules. So it's not actually a module itself, but it's expected that it has
#   unresolved symbols.)
%define _disable_ld_no_undefined 1

# enable/disable vala
%bcond_without vala

# enable/disable docs
%bcond_without docs

# disable ovs for now as we don't have openvswitch
%bcond_with ovs

# Install and use firewalld zone for shared mode
%bcond_with firewalld_zone

# _without = gnutls, _with = nss
%bcond_without crypto_gnutls

%global ppp_ver	%(rpm -q --queryformat "%{VERSION}" ppp)

%define major_nm		0
%define libnm			%mklibname nm %{major_nm}
%define libnm_devel		%mklibname -d nm

%define gimajor_nmclient	1.0
%define nmclient_gi		%mklibname nmclient-gir %{gimajor_nmclient}

%define gimajor_nm              1.0
%define nm_gi			%mklibname nm-gir %{gimajor_nm}

%define url_ver %{lua: ver = rpm.expand("%{version}"); majmin, count1 = string.gsub(ver, "^(%d+%.%d+).*", "%1", 1); if count1 == 0 then print(ver); return; end; maj, count2 = string.gsub(majmin, "^(%d+).*", "%1", 1); if count2 == 0 then print(majmin) elseif tonumber(majmin) < 40 then print(majmin) else print(maj) end}

%define	rname		NetworkManager

# meson option -Ddist_version defines where plugins are installed:
# -Ddist_version=%%{version}-%{release} --> %%{_libdir}/%%{rname}/%%{version}-%%{release}
# -Ddist_version=%%{version} --> %%{_libdir}/%%{rname}/%%{version}
%define nmplugindir	%{_libdir}/%{rname}/%{version}

Name:		networkmanager
Summary:	Network management daemon
Version:	1.51.4
Release:	%mkrel 1
Group:		System/Base
License:	GPLv2+
URL:		https://wiki.gnome.org/Projects/NetworkManager
Source0:	https://download.gnome.org/sources/NetworkManager/%{url_ver}/%{rname}-%{version}.tar.xz
Source1:	README.urpmi
Source3:	nm-poke-nscd
# Upstream patches
#
# Mageia patches
# (blino) read WIRELESS_ESSID, but kept ESSID as fallback
Patch201:	NetworkManager-1.30.2-mga-wireless_essid.patch

BuildRequires:	meson
BuildRequires:	pkgconfig(audit)
BuildRequires:	pkgconfig(libpsl)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libnl-3.0)
BuildRequires:	wpa_supplicant
BuildRequires:	libiw-devel
BuildRequires:	pkgconfig(dbus-glib-1)

# looks like both crypto backends are always built
# https://gitlab.freedesktop.org/NetworkManager/NetworkManager/-/commit/243051a8a62a01dc34a89cf9b3ea4d3ad961805b
BuildRequires:	pkgconfig(gnutls)
BuildRequires:	pkgconfig(nss)

BuildRequires:	intltool
BuildRequires:	gtk-doc
BuildRequires:	pkgconfig(ext2fs)
BuildRequires:	ppp-devel
BuildRequires:	polkit-1-devel
BuildRequires:	pkgconfig(libndp)
BuildRequires:	pkgconfig(uuid)
BuildRequires:	pkgconfig(gudev-1.0)
BuildRequires:	pkgconfig(jansson)
BuildRequires:	pkgconfig(readline)
#BuildRequires:	dhcp-client
BuildRequires:	iptables
BuildRequires:	pkgconfig(gobject-introspection-1.0) >= 0.10.3
BuildRequires:	python3-gobject3
# (bor) for systemd support, pkg-config; move to systemd?
BuildRequires:	systemd-units
BuildRequires:	pkgconfig(libsystemd)
BuildRequires:	pkgconfig(mm-glib)
BuildRequires:	pkgconfig(mobile-broadband-provider-info)
%if %{with vala}
BuildRequires:	pkgconfig(vapigen)
%endif
# connection check:
BuildRequires:	pkgconfig(libcurl) >= 7.24.0
# Bluez5 DUN support:
BuildRequires:	pkgconfig(bluez) >= 5
# For nmtui
BuildRequires:	pkgconfig(libnewt) >= 0.52.15
# libteam
BuildRequires:	pkgconfig(libteamdctl) >= 1.9
# dnsmasq
BuildRequires:	dnsmasq
Requires:	networkmanager-wifi
Recommends:	networkmanager-wwan
Recommends:	networkmanager-team
Recommends:	networkmanager-adsl
Recommends:	networkmanager-bluetooth
Recommends:	networkmanager-ppp
Recommends:	networkmanager-l2tp
Recommends:	networkmanager-openconnect
Recommends:	networkmanager-libreswan
Recommends:	networkmanager-openvpn
Recommends:	networkmanager-pptp
Recommends:	networkmanager-vpnc
Recommends:	networkmanager-tui
Provides:	NetworkManager = %{version}-%{release}
Requires(post):		rpm-helper >= 0.24.8-1
Requires(preun):	rpm-helper >= 0.24.8-1
# drop old cnetworkmanager (nmcli does the same and perhaps even more)
Obsoletes:	cnetworkmanager < 0.21.1-10

%description
NetworkManager is a system service that manages network interfaces and
connections based on user or automatic configuration. It supports Ethernet,
Bridge, Bond, VLAN, Team, InfiniBand, Wi-Fi, mobile broadband (WWAN), PPPoE and
other devices, and supports a variety of different VPN services.

%package adsl
Summary:	ADSL device plugin for NetworkManager
Group:		System/Base
Requires:	%{name} = %{version}-%{release}

%description adsl
This package contains NetworkManager support for ADSL devices.

%package bluetooth
Summary:	Bluetooth device plugin for NetworkManager
Group:		System/Base
Requires:	%{name} = %{version}-%{release}
Requires:	%{name}-wwan = %{version}-%{release}
Requires:	bluez >= 5

%description bluetooth
This package contains NetworkManager support for Bluetooth devices.

%package team
Summary:	Team device plugin for NetworkManager
Group:		System/Base
Requires:	%{name} = %{version}-%{release}

%description team
This package contains NetworkManager support for team devices.

%package wifi
Summary:	Wifi plugin for NetworkManager
Group:		System/Base
Requires:	%{name} = %{version}-%{release}
Requires:	wpa_supplicant
Requires:	wireless-tools

%description wifi
This package contains NetworkManager support for Wifi and OLPC devices.

%package wwan
Summary:	Mobile broadband device plugin for NetworkManager
Group:		System/Base
Requires:	%{name} = %{version}-%{release}
Requires:	modemmanager
Requires:	mobile-broadband-provider-info

%description wwan
This package contains NetworkManager support for mobile broadband (WWAN)
devices.

%if %{with ovs}
%package	ovs
Summary:	OpenVSwitch device plugin for NetworkManager
Group:		System/Base
Requires:	%{name} = %{version}-%{release}
Requires:	openvswitch

%description ovs
This package contains NetworkManager support for OpenVSwitch bridges.
%endif

%package ppp
Summary:	PPP plugin for NetworkManager
Group:		System/Base
Requires:	%{name} = %{version}-%{release}
Requires:	ppp = %{ppp_ver}

%description ppp
This package contains NetworkManager support for PPP.

%package	tui
Summary:	Text User Interface for NetworkManager based on curses
Group:		System/Base

%description	tui
This adds a curses-based "TUI" (Text User Interface) to NetworkManager, to
allow performing some of the operations supported by nm-connection-editor and
nm-applet in a non-graphical environment.

%package -n	%{libnm}
Summary:	Shared library for nm
Group:		System/Libraries

%description -n %{libnm}
Shared library for nm.

%package -n	%{libnm_devel}
Summary:	Development files for nm
Group:		Development/C
Provides:	libnm-devel = %{version}-%{release}
Requires:	%{nm_gi} = %{version}-%{release}

%description -n %{libnm_devel}
Development files for nm.

%package -n	%{nm_gi}
Summary:	GObject Introspection interface library for NM
Group:		System/Libraries
Requires:	%{libnm} = %{version}-%{release}

%description -n %{nm_gi}
GObject Introspection interface library for NM.

%prep
%setup -q -n %{rname}-%{version}
%autopatch -p1

%build
%meson \
	-Dsystemdsystemunitdir=%{_unitdir} \
	-Dsystem_ca_path=/etc/pki/tls/certs \
	-Dudev_dir=%{_prefix}/lib/udev/ \
	-Ddbus_conf_dir=%{_datadir}/dbus-1/system.d/ \
	-Dkernel_firmware_dir=/lib/firmware \
	-Druntime_dir=%{_rundir} \
	-Diptables=%{_sbindir}/iptables \
	-Dnft=%{_sbindir}/nft \
	-Ddnsmasq=%{_sbindir}/dnsmasq \
	-Dmodprobe=%{_sbindir}/modprobe \
	\
	\
	-Ddist_version=%{version} \
	-Dsession_tracking_consolekit=false \
	-Dsession_tracking=systemd \
	-Dsuspend_resume=systemd \
	-Dpolkit=true \
	-Dconfig_auth_polkit_default=default \
	-Dmodify_system=true \
	-Dpolkit_agent_helper_1=%{_prefix}/lib/polkit-1/polkit-agent-helper-1 \
	-Dselinux=false \
	-Dsystemd_journal=true \
	-Dconfig_logging_backend_default=journal \
	-Dconfig_wifi_backend_default=wpa_supplicant \
	-Dhostname_persist=default \
	-Dlibaudit=yes-disabled-by-default \
	\
	\
	-Dwext=true \
	-Dwifi=true \
	-Diwd=true \
	-Dppp=true \
	-Dpppd=%{_sbindir}/pppd \
	-Dpppd_plugin_dir=%{_libdir}/pppd/%{ppp_ver} \
	-Dmodem_manager=true \
	\
	-Dofono=false \
	-Dconcheck=true \
	-Dteamdctl=true \
	-Dovs=%{?with_ovs:true}%{!?with_ovs:false} \
	-Dnmcli=true \
	-Dnmtui=true \
	-Dnm_cloud_setup=false \
	-Dbluez5_dun=false \
	-Debpf=false \
	\
	\
	-Dconfig_plugins_default=ifcfg-rh \
	-Difcfg_rh=true \
	-Difupdown=false \
	-Dconfig_migrate_ifcfg_rh_default=false \
	\
	\
	-Dresolvconf=false \
	-Dnetconfig=false \
	-Dconfig_dns_rc_manager_default=auto \
	\
	\
	-Ddhclient=true \
	-Ddhcpcanon=false \
	-Ddhcpcd=true \
	-Dconfig_dhcp_default=internal \
	\
	\
	-Dintrospection=true \
	-Dvapi=%{?with_vala:true}%{!?with_vala:false} \
	-Ddocs=%{?with_docs:true}%{!?with_docs:false} \
	-Dtests=yes \
	-Dfirewalld_zone=%{?with_firewalld_zone:true}%{!?with_firewalld_zone:false} \
	-Dmore_asserts=0 \
	-Dmore_logging=false \
	-Dvalgrind=false \
	-Dvalgrind_suppressions='' \
	-Dld_gc=true \
	-Dlibpsl=true \
	-Dcrypto=%{?with_crypto_gnutls:gnutls}%{!?with_crypto_gnutls:nss} \
	-Dqt=false \
	-Dreadline=libreadline
%meson_build

%install
%meson_install

install -d %{buildroot}%{_libexecdir}
install -m755 %{SOURCE3} %{buildroot}%{_libexecdir}/

install -d %{buildroot}%{_sysconfdir}/%{rname}/conf.d/
cat > %{buildroot}%{_sysconfdir}/%{rname}/%{rname}.conf << EOF
[main]
plugins=ifcfg-rh,keyfile
dhcp=internal
EOF

# Create netprofile module
install -d %{buildroot}%{_sysconfdir}/netprofile/modules/
cat > %{buildroot}%{_sysconfdir}/netprofile/modules/01_networkmanager << EOF
# netprofile module
#
# this module contains settings for saving/restore the NetworkManager configuration
# in different network profiles

NAME="networkmanager"
DESCRIPTION="Networkmanager connection settings"

# list of files to be saved by netprofile
FILES="/etc/NetworkManager/"

# list of services to be restarted by netprofile
SERVICES="networkmanager"
EOF

chmod  755 %{buildroot}%{_sysconfdir}/netprofile/modules/01_networkmanager

# create a VPN directory
install -d %{buildroot}%{_sysconfdir}/%{rname}/VPN

# create keyfile plugin system-settings directory
install -d %{buildroot}%{_sysconfdir}/%{rname}/system-connections

install -d %{buildroot}%{_prefix}/lib/%{rname}/conf.d/
install -d %{buildroot}%{_prefix}/lib/%{rname}/VPN/
install -d %{buildroot}%{_localstatedir}/lib/%{rname}/
touch %{buildroot}%{_localstatedir}/lib/%{rname}/%{rname}-intern.conf

# create dir for dnsmasq configs
install -d %{buildroot}%{_sysconfdir}/%{rname}/dnsmasq.d/
install -d %{buildroot}%{_sysconfdir}/%{rname}/dnsmasq-shared.d/

# Disable touching MAC addresses on devices not supporting it
install -Dpm644 examples/nm-conf.d/31-mac-addr-change.conf \
  %{buildroot}%{_prefix}/lib/%{rname}/conf.d/

# Add readme displayed by urpmi
install -pm644 %{SOURCE1} .

# provide networkmanager daemon via systemd as well
pushd %{buildroot}/%{_unitdir}
ln -s NetworkManager.service %{name}.service
ln -s NetworkManager.service nm.service
popd

%find_lang %{rname}

#post
# (cg) Do not enable NM by default. Doing so means that all configuration done
# via draknetcenter suddenly no longer applies if this package is installed
# on a running system. Likewise, configuration made during install might not
# apply either when booting which is again bad.
# Users can now enable NM in drakxservices and on reboot all interfaces will
# automatically flip over to NM. This behaviour is now deterministic and can
# be documented cleanly rather than the previous mess.
#%_post_service %{name}

%preun
%_preun_service %{name}

%files -f %{rname}.lang
%doc AUTHORS CONTRIBUTING.md ChangeLog NEWS TODO
%doc README.urpmi
%doc %{_docdir}/%{rname}/examples/server.conf
%if %{with docs}
%doc %{_datadir}/gtk-doc/html/%{rname}/
%endif
%{_datadir}/dbus-1/system.d/org.freedesktop.NetworkManager.conf
%{_datadir}/dbus-1/system.d/nm-dispatcher.conf
%{_datadir}/dbus-1/system.d/nm-ifcfg-rh.conf
%{_datadir}/dbus-1/system.d/nm-priv-helper.conf
%dir %{_sysconfdir}/%{rname}/
%config(noreplace) %{_sysconfdir}/%{rname}/NetworkManager.conf
%dir %{_sysconfdir}/%{rname}/conf.d/
%dir %{_sysconfdir}/%{rname}/dispatcher.d/
%dir %{_sysconfdir}/%{rname}/dnsmasq.d/
%dir %{_sysconfdir}/%{rname}/dnsmasq-shared.d/
%dir %{_sysconfdir}/%{rname}/system-connections/
%dir %{_sysconfdir}/%{rname}/VPN/
%{_sysconfdir}/netprofile/modules/01_networkmanager
%{_sbindir}/%{rname}
%{_bindir}/nmcli
%{_bindir}/nm-online
%{_libexecdir}/nm-daemon-helper
%{_libexecdir}/nm-dispatcher
%{_libexecdir}/nm-dhcp-helper
%{_libexecdir}/nm-initrd-generator
%{_libexecdir}/nm-poke-nscd
%{_libexecdir}/nm-priv-helper
%{_libexecdir}/nm-ifdown
%{_libexecdir}/nm-ifup
%if %{with docs}
%{_mandir}/man1/*.1*
%exclude %{_mandir}/man1/nmtui*.1*
%{_mandir}/man5/*.5*
%{_mandir}/man7/*.7*
%{_mandir}/man8/*.8*
%endif
%dir %{nmplugindir}/
%{nmplugindir}/libnm-settings-plugin-ifcfg-rh.so
%dir %{_prefix}/lib/%{rname}/
%dir %{_prefix}/lib/%{rname}/conf.d/
%{_prefix}/lib/%{rname}/conf.d/31-mac-addr-change.conf
%dir %{_prefix}/lib/%{rname}/VPN/
%dir %{_localstatedir}/lib/%{rname}/
%ghost %{_localstatedir}/lib/%{rname}/%{rname}-intern.conf
%{_udevrulesdir}/*.rules
%if %{with firewalld_zone}
%{_prefix}/lib/firewalld/zones/nm-shared.xml
%endif
%{_unitdir}/NetworkManager.service
%{_unitdir}/networkmanager.service
%{_unitdir}/nm.service
%{_unitdir}/nm-priv-helper.service
%{_unitdir}/NetworkManager-wait-online.service
%{_unitdir}/NetworkManager-dispatcher.service
%{_datadir}/dbus-1/system-services/org.freedesktop.nm_dispatcher.service
%{_datadir}/dbus-1/system-services/org.freedesktop.nm_priv_helper.service
%{_datadir}/dbus-1/interfaces/org.freedesktop.NetworkManager.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.NetworkManager.*.xml
%{_datadir}/polkit-1/actions/org.freedesktop.NetworkManager.policy
%{_datadir}/bash-completion/completions/nmcli

%files adsl
%{nmplugindir}/libnm-device-plugin-adsl.so

%files bluetooth
%{nmplugindir}/libnm-device-plugin-bluetooth.so

%files team
%{nmplugindir}/libnm-device-plugin-team.so

%files wifi
%{nmplugindir}/libnm-device-plugin-wifi.so

%files wwan
%{nmplugindir}/libnm-device-plugin-wwan.so
%{nmplugindir}/libnm-wwan.so

%if %{with ovs}
%files ovs
%{nmplugindir}/libnm-device-plugin-ovs.so
%{_prefix}/lib/systemd/system/NetworkManager.service.d/NetworkManager-ovs.conf
%endif

%files ppp
%{_libdir}/pppd/%{ppp_ver}/nm-pppd-plugin.so
%{nmplugindir}/libnm-ppp-plugin.so

%files tui
%{_bindir}/nmtui
%{_bindir}/nmtui-connect
%{_bindir}/nmtui-edit
%{_bindir}/nmtui-hostname
%if %{with docs}
%{_mandir}/man1/nmtui*.1*
%endif

%files -n %{libnm}
%{_libdir}/libnm.so.%{major_nm}{,.*}

%files -n %{nm_gi}
%{_libdir}/girepository-1.0/NM-%{gimajor_nm}.typelib

%files -n %{libnm_devel}
%doc %{_datadir}/gtk-doc/html/libnm/
%dir %{_includedir}/libnm
%{_includedir}/libnm/*.h
%{_libdir}/pkgconfig/libnm.pc
%{_libdir}/libnm.so
%{_datadir}/gir-1.0/NM-1.0.gir
%if %{with vala}
%{_datadir}/vala/vapi/libnm.deps
%{_datadir}/vala/vapi/libnm.vapi
%endif


%changelog
* Mon Jan 06 2025 wally <wally> 1.51.4-1.mga10
+ Revision: 2135795
- new version 1.51.4

* Mon Jan 06 2025 wally <wally> 1.50.0-2.mga10
+ Revision: 2135679
- rebuild for ppp 2.5.2

* Fri Oct 25 2024 wally <wally> 1.50.0-1.mga10
+ Revision: 2111203
- new version 1.50.0

* Tue Sep 10 2024 wally <wally> 1.49.90-1.mga10
+ Revision: 2094984
- new version 1.49.90 (1.50-rc1)

* Thu Aug 29 2024 wally <wally> 1.48.10-1.mga10
+ Revision: 2092184
- new version 1.48.10

* Sat Aug 17 2024 wally <wally> 1.48.8-1.mga10
+ Revision: 2086845
- new version 1.48.8

* Thu Feb 22 2024 wally <wally> 1.46.0-1.mga10
+ Revision: 2043288
- new version 1.46.0

* Sun Jan 28 2024 wally <wally> 1.44.2-1.mga10
+ Revision: 2035589
- new version 1.44.2

* Sun Aug 27 2023 wally <wally> 1.44.0-1.mga10
+ Revision: 1980296
- new version 1.44.0
- enable iwd support
- drop resolvconf support

* Sun Apr 30 2023 wally <wally> 1.40.18-2.mga9
+ Revision: 1955485
- set main.rc-manager default setting to 'auto'

* Sun Apr 16 2023 wally <wally> 1.40.18-1.mga9
+ Revision: 1953070
- new version 1.40.18

* Sun Apr 02 2023 wally <wally> 1.40.16-1.mga9
+ Revision: 1951247
- new version 1.40.16

* Mon Jan 30 2023 wally <wally> 1.40.12-1.mga9
+ Revision: 1937046
- new version 1.40.12

* Mon Jan 16 2023 wally <wally> 1.40.10-1.mga9
+ Revision: 1933817
- new version 1.40.10

* Sun Oct 23 2022 ghibo <ghibo> 1.40.2-2.mga9
+ Revision: 1898614
- Rebuild against latest xl2tpd

* Tue Oct 18 2022 ovitters <ovitters> 1.40.2-1.mga9
+ Revision: 1897449
- new version 1.40.2

* Sat Aug 27 2022 tmb <tmb> 1.40.0-1.mga9
+ Revision: 1881227
- update to 1.40.0

* Mon Apr 04 2022 umeabot <umeabot> 1.32.12-2.mga9
+ Revision: 1843747
- Mageia 9 Mass Rebuild

* Wed Sep 22 2021 ovitters <ovitters> 1.32.12-1.mga9
+ Revision: 1746186
- new version 1.32.12

* Wed Aug 18 2021 ovitters <ovitters> 1.32.10-1.mga9
+ Revision: 1741837
- new version 1.32.10

* Wed Jul 28 2021 ovitters <ovitters> 1.32.6-1.mga9
+ Revision: 1738078
- new version 1.32.6

* Tue Jul 20 2021 ovitters <ovitters> 1.32.4-1.mga9
+ Revision: 1737240
- new version 1.32.4

* Sun Jul 18 2021 wally <wally> 1.32.2-2.mga9
+ Revision: 1736827
- Rebuild for ppp 2.4.9

* Wed Jun 30 2021 ovitters <ovitters> 1.32.2-1.mga9
+ Revision: 1734371
- new version 1.32.2

* Fri Jun 18 2021 ovitters <ovitters> 1.32.0-1.mga9
+ Revision: 1731077
- new version 1.32.0

* Mon Apr 19 2021 ovitters <ovitters> 1.30.4-1.mga9
+ Revision: 1717088
- new version 1.30.4

* Thu Mar 25 2021 ovitters <ovitters> 1.30.2-1.mga9
+ Revision: 1709976
- new version 1.30.2
- resync patch

* Mon Dec 07 2020 ovitters <ovitters> 1.26.6-1.mga8
+ Revision: 1654133
- new version 1.26.6

* Wed Oct 14 2020 ovitters <ovitters> 1.26.4-1.mga8
+ Revision: 1635802
- new version 1.26.4
- dropped merged patch 0001-build-docs-fix-generated-XML-syntax-in-tools-generat.patch

* Thu Sep 24 2020 wally <wally> 1.26.2-2.mga8
+ Revision: 1629854
- add upstream patch to fix build
- rebuild for ppp 2.4.8

* Wed Aug 19 2020 ovitters <ovitters> 1.26.2-1.mga8
+ Revision: 1615845
- new version 1.26.2

* Sat Jul 25 2020 ovitters <ovitters> 1.26.0-2.mga8
+ Revision: 1609006
- nm-poke-nscd: fix booted-with-systemd check

* Mon Jul 13 2020 ovitters <ovitters> 1.26.0-1.mga8
+ Revision: 1605796
- new version 1.26.0

* Sun Jun 28 2020 ovitters <ovitters> 1.25.91-1.mga8
+ Revision: 1600147
- new version 1.25.91

* Wed Jun 17 2020 wally <wally> 1.25.90-1.mga8
+ Revision: 1594770
- new version 1.25.90

* Sun Jun 07 2020 wally <wally> 1.24.2-3.mga8
+ Revision: 1590817
- drop MAC address discovering patch which breaks ifcfg-rh plugin
- simplify WIRELESS_ESSID patch

* Sat Jun 06 2020 wally <wally> 1.24.2-2.mga8
+ Revision: 1590740
- disable touching MAC addresses on devices not supporting it
- add nm.service alias for systemd

* Sun May 31 2020 ovitters <ovitters> 1.24.2-1.mga8
+ Revision: 1589161
- new version 1.24.2

* Fri May 08 2020 ovitters <ovitters> 1.24.0-1.mga8
+ Revision: 1581797
- new version 1.24.0

* Thu Mar 12 2020 ovitters <ovitters> 1.22.10-1.mga8
+ Revision: 1555867
- new version 1.22.10

* Thu Feb 20 2020 umeabot <umeabot> 1.22.8-2.mga8
+ Revision: 1546057
- Mageia 8 Mass Rebuild

* Tue Feb 18 2020 ovitters <ovitters> 1.22.8-1.mga8
+ Revision: 1541315
- new version 1.22.8

* Fri Jan 31 2020 ovitters <ovitters> 1.22.6-1.mga8
+ Revision: 1485833
- new version 1.22.6

* Fri Jan 10 2020 ovitters <ovitters> 1.22.4-1.mga8
+ Revision: 1477490
- new version 1.22.4

* Sat Jan 04 2020 luigiwalser <luigiwalser> 1.22.2-2.mga8
+ Revision: 1475991
- rebuild for readline

* Tue Dec 24 2019 ovitters <ovitters> 1.22.2-1.mga8
+ Revision: 1469889
- new version 1.22.2

* Fri Dec 20 2019 wally <wally> 1.22.0-2.mga8
+ Revision: 1469069
- add mobile-broadband-provider-info requires to wwan

* Fri Dec 20 2019 wally <wally> 1.22.0-1.mga8
+ Revision: 1469066
- update summary
+ ovitters <ovitters>
- new version 1.22.0

* Mon Nov 25 2019 ovitters <ovitters> 1.20.8-1.mga8
+ Revision: 1462775
- new version 1.20.8

* Wed Nov 06 2019 ovitters <ovitters> 1.20.6-1.mga8
+ Revision: 1458420
- new version 1.20.6

* Mon Sep 30 2019 ovitters <ovitters> 1.20.4-1.mga8
+ Revision: 1448249
- new version 1.20.4
- new version 1.20.2

* Tue Aug 06 2019 ovitters <ovitters> 1.20.0-1.mga8
+ Revision: 1427674
- new version 1.20.0

* Sat Aug 03 2019 wally <wally> 1.19.90-2.mga8
+ Revision: 1427036
- make nm to obsolete old cmd client cnetworkmanager
- disable consolekit session tracking support

* Fri Aug 02 2019 wally <wally> 1.19.90-1.mga8
+ Revision: 1426874
- new version 1.19.90
- drop deprecated libnm-glib libs and pkgs

* Sat Jul 27 2019 wally <wally> 1.18.2-1.mga8
+ Revision: 1424540
- new version 1.18.2
- rediff discover-mac-address.patch

* Wed Apr 24 2019 tmb <tmb> 1.18.1-1.mga7
+ Revision: 1395190
- update to 1.18.1

* Thu Apr 18 2019 umeabot <umeabot> 1.16.0-2.mga7
+ Revision: 1392837
- Rebuild with meson 0.50.1

* Fri Mar 15 2019 ovitters <ovitters> 1.16.0-1.mga7
+ Revision: 1377458
- new version 1.16.0

* Mon Mar 11 2019 ovitters <ovitters> 1.15.91-1.mga7
+ Revision: 1374100
- new version 1.15.91

* Sun Feb 24 2019 wally <wally> 1.15.90-1.mga7
+ Revision: 1369902
- new version 1.15.90 (1.16-rc1)

* Sat Feb 23 2019 wally <wally> 1.14.6-1.mga7
+ Revision: 1369573
- new version 1.14.6
- drop upstreamed patches and files
- update discover-mac-address.patch

* Sat Feb 16 2019 wally <wally> 1.14.4-5.mga7
+ Revision: 1367512
- use /run as runstatedir instead of /var/run
- build using python3

* Sat Jan 26 2019 wally <wally> 1.14.4-4.mga7
+ Revision: 1361015
- don't require iptables/iproute2

* Sun Jan 20 2019 wally <wally> 1.14.4-3.mga7
+ Revision: 1358464
- switch to meson build
- disable obsolete ibft plugin

* Sun Nov 04 2018 tmb <tmb> 1.14.4-2.mga7
+ Revision: 1328101
- dhcp6: make sure we have enough space for the DHCP6 option header
  (CVE-2018-15688)

* Sat Oct 27 2018 wally <wally> 1.14.4-1.mga7
+ Revision: 1326221
- new version 1.14.4
- switch crypto to gnutls

* Tue Sep 18 2018 ovitters <ovitters> 1.12.4-1.mga7
+ Revision: 1260180
- new version 1.12.4
- dropped merged patch NetworkManager-1.12.2-fix-compile-error-due-to-NM_AVAILABLE_IN_1_12_2-macro.patch

* Sat Sep 08 2018 daviddavid <daviddavid> 1.12.2-2.mga7
+ Revision: 1257755
- add patch to fix compile error due to NM_AVAILABLE_IN_1_12_2 macro

* Wed Jul 25 2018 ovitters <ovitters> 1.12.2-1.mga7
+ Revision: 1245196
- new version 1.12.2

* Sun Jul 01 2018 guillomovitch <guillomovitch> 1.12.0-1.mga7
+ Revision: 1241032
- new version 1.12.0

* Sat Jun 16 2018 ovitters <ovitters> 1.10.10-1.mga7
+ Revision: 1237187
- new version 1.10.10

* Fri May 11 2018 ovitters <ovitters> 1.10.8-1.mga7
+ Revision: 1228314
- new version 1.10.8

* Mon Mar 12 2018 ovitters <ovitters> 1.10.6-1.mga7
+ Revision: 1208474
- new version 1.10.6

* Mon Feb 05 2018 ovitters <ovitters> 1.10.4-1.mga7
+ Revision: 1198965
- new version 1.10.4
+ wally <wally>
- drop old conflicts

* Tue Dec 12 2017 ovitters <ovitters> 1.10.2-1.mga7
+ Revision: 1182262
- new version 1.10.2

* Fri Nov 10 2017 ovitters <ovitters> 1.10.0-1.mga7
+ Revision: 1176782
- new version 1.10.0

* Mon Nov 06 2017 wally <wally> 1.9.90-1.mga7
+ Revision: 1176263
- new version 1.9.90 (1.10-rc1)

* Wed Oct 11 2017 wally <wally> 1.8.4-4.mga7
+ Revision: 1171004
- build with libpsl
- add patches to add support for DHCPv4 domain search list (option 119) to internal dhcp client

* Tue Oct 03 2017 wally <wally> 1.8.4-3.mga7
+ Revision: 1167944
- install /usr/lib/NetworkManager/VPN/

* Tue Oct 03 2017 wally <wally> 1.8.4-2.mga7
+ Revision: 1167883
- fix ppp requires

* Wed Sep 27 2017 ovitters <ovitters> 1.8.4-1.mga7
+ Revision: 1160493
- new version 1.8.4

* Mon Jul 17 2017 ovitters <ovitters> 1.8.2-1.mga7
+ Revision: 1124443
- new version 1.8.2

* Fri May 26 2017 ovitters <ovitters> 1.8.0-1.mga6
+ Revision: 1104726
- new version 1.8.0
- rediff patches

* Sat May 06 2017 luigiwalser <luigiwalser> 1.6.2-5.mga6
+ Revision: 1099316
- fix format security errors

* Thu Feb 23 2017 wally <wally> 1.6.2-4.mga6
+ Revision: 1087510
- drop conflicts for connman (connman isn't enabled by default anymore and README.urpmi was added to connman to explain to not enable connman and networkmanager at the same time)

* Sun Feb 19 2017 ovitters <ovitters> 1.6.2-3.mga6
+ Revision: 1086971
- add conflict on connman as it pretends to be NM (mga#20286)

* Sun Feb 19 2017 wally <wally> 1.6.2-2.mga6
+ Revision: 1086899
- move nmtui man pages to correct pkg
- split out device plugins
- require wifi device plugin by default and recommend others
- drop unneeded requires for mobile-broadband-provider-info
- create /etc/NetworkManager/dnsmasq-shared.d/

* Wed Feb 15 2017 ovitters <ovitters> 1.6.2-1.mga6
+ Revision: 1086303
- new version 1.6.2
- dropped merged patch 3

* Fri Feb 10 2017 wally <wally> 1.6.0-11.mga6
+ Revision: 1085508
- fix pppd plugin dir
- no need to require optional dnsmasq-base
- add some missing dirs/files

* Wed Feb 08 2017 wally <wally> 1.6.0-10.mga6
+ Revision: 1085153
- split out NetworkManager typelib
- move gir files to correct devel pkgs
- don't pkg libnm devel files twice
- tag gtk-docs as docs
- move docs under %%_docdir
- create /etc/NetworkManager/conf.d/

* Mon Feb 06 2017 wally <wally> 1.6.0-9.mga6
+ Revision: 1085040
- add patch from upstream to fix interpreting missing MAC_ADDRESS_RANDOMIZATION as permanent address with ifcfg-rh plugin
- rediff P11 (mga-wireless_essid.patch) to apply with upstream patch added

* Mon Feb 06 2017 wally <wally> 1.6.0-8.mga6
+ Revision: 1085008
- update P10 (discover-mac-address.patch) one more time

* Sun Feb 05 2017 wally <wally> 1.6.0-7.mga6
+ Revision: 1084858
- update P10 (discover-mac-address.patch)

* Sat Feb 04 2017 wally <wally> 1.6.0-6.mga6
+ Revision: 1084834
- use internal dhcp client by default
- drop dhcp-client requires

* Sat Feb 04 2017 wally <wally> 1.6.0-5.mga6
+ Revision: 1084828
- explicitly enable dhclient and dhcpcd support

* Sat Feb 04 2017 wally <wally> 1.6.0-4.mga6
+ Revision: 1084823
- add libaudit support (disabled by default)
- drop unneeded README-mdvplugin.urpmi file

* Sat Feb 04 2017 wally <wally> 1.6.0-3.mga6
+ Revision: 1084795
- bring back P10 (discover-mac-address.patch) also

* Sat Feb 04 2017 wally <wally> 1.6.0-2.mga6
+ Revision: 1084777
- bring back P11 (wireless_essid.patch) to see if it fixes wireless connection problems

* Sun Jan 29 2017 ovitters <ovitters> 1.6.0-1.mga6
+ Revision: 1084021
- new version 1.6.0
- dropped merged patch 2
- dropped merged patch 1

* Fri Dec 16 2016 ovitters <ovitters> 1.4.4-1.mga6
+ Revision: 1075589
- new version 1.4.4

* Sun Oct 02 2016 ovitters <ovitters> 1.4.2-1.mga6
+ Revision: 1058086
- new version 1.4.2

* Sun Aug 28 2016 ovitters <ovitters> 1.4.0-2.mga6
+ Revision: 1049320
- really enable dnsmasq support

* Thu Aug 25 2016 ovitters <ovitters> 1.4.0-1.mga6
+ Revision: 1048937
- new version 1.4.0

* Wed Aug 03 2016 ovitters <ovitters> 1.2.4-1.mga6
+ Revision: 1044405
- new version 1.2.4

* Tue Jun 07 2016 tv <tv> 1.2.2-2.mga6
+ Revision: 1020648
- adjust BRs for latest systemd

* Wed May 11 2016 ovitters <ovitters> 1.2.2-1.mga6
+ Revision: 1012929
- new version 1.2.2
- dropped merged patch 3

* Sat Apr 30 2016 tmb <tmb> 1.2.0-2.mga6
+ Revision: 1008344
- linux-platform: re-read the link type if the name changed

* Wed Apr 20 2016 ovitters <ovitters> 1.2.0-1.mga6
+ Revision: 1003823
- new version 1.2.0

* Tue Apr 12 2016 ovitters <ovitters> 1.1.94-1.mga6
+ Revision: 1000812
- new version 1.1.94

* Wed Apr 06 2016 ovitters <ovitters> 1.1.93-1.mga6
+ Revision: 998898
- new version 1.1.93

* Tue Mar 29 2016 wally <wally> 1.1.92-1.mga6
+ Revision: 996326
- new version 1.1.92
- drop DHCPv6 patch from upstream
+ ovitters <ovitters>
- enable libreswan
+ luigiwalser <luigiwalser>
- do not recommend networkmanager-openswan as it is not packaged

* Wed Mar 16 2016 wally <wally> 1.1.91-3.mga6
+ Revision: 992105
- add upstream patch to enable internal DHCPv6 client support
- drop useless P2 as we force resolvconf usage anyways

* Sun Mar 13 2016 wally <wally> 1.1.91-2.mga6
+ Revision: 990190
- rediff P11 to apply with --fuzz=0

* Sun Mar 13 2016 wally <wally> 1.1.91-1.mga6
+ Revision: 990156
- disable P2 for now
- new version 1.1.91
- rediff P11

* Thu Feb 11 2016 ovitters <ovitters> 1.1.90-1.mga6
+ Revision: 955798
- rediff patch (don't get the git instructions)
- new version 1.1.90

* Wed Dec 23 2015 ovitters <ovitters> 1.0.10-1.mga6
+ Revision: 913796
- new version 1.0.10

* Mon Nov 23 2015 ovitters <ovitters> 1.0.8-1.mga6
+ Revision: 905091
- new version 1.0.8

* Thu Aug 27 2015 ovitters <ovitters> 1.0.6-1.mga6
+ Revision: 870233
- new version 1.0.6

* Tue Jul 14 2015 ovitters <ovitters> 1.0.4-1.mga6
+ Revision: 854036
- new version 1.0.4

* Mon Jun 29 2015 wally <wally> 1.0.2-3.mga6
+ Revision: 847798
- add requires for gir pkg to devel pkg

* Mon May 11 2015 tmb <tmb> 1.0.2-2.mga5
+ Revision: 821736
- submit to release

* Wed May 06 2015 shlomif <shlomif> 1.0.2-1.mga5
+ Revision: 821350
- New version 1.0.2 with fixes to MGA#15862 .

* Thu Feb 19 2015 ovitters <ovitters> 1.0.0-4.mga5
+ Revision: 815854
- enable libteam support
- update description as it can now be used on servers as well

* Fri Feb 06 2015 ovitters <ovitters> 1.0.0-3.mga5
+ Revision: 813707
- add tui (text user interface) and recommend it
- enable concheck
- also recommend networkmanager-openswan
- improve text in the urpmi upgrade message

* Fri Feb 06 2015 ovitters <ovitters> 1.0.0-2.mga5
+ Revision: 813644
- recommend the networkmanager VPN packages l2tp,openconnect,openvpn,pptp,vpnc

* Thu Jan 29 2015 colin <colin> 1.0.0-1.mga5
+ Revision: 812687
- New version: 1.0.0
- Rediffed patches (MAC address discovery patch was broken for a year)
- Be more explicit with configure args (we may want to enable tui)
- Add new sub-packages for new libraries

* Wed Oct 15 2014 umeabot <umeabot> 0.9.10.0-7.mga5
+ Revision: 750830
- Second Mageia 5 Mass Rebuild

* Fri Sep 26 2014 wally <wally> 0.9.10.0-6.mga5
+ Revision: 724948
- rebuild with new rpm-mageia-setup to generate requires for .typelib files

* Tue Sep 16 2014 umeabot <umeabot> 0.9.10.0-5.mga5
+ Revision: 682866
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes

* Thu Sep 04 2014 colin <colin> 0.9.10.0-4.mga5
+ Revision: 672063
- Rebuild for new systemd

* Thu Aug 28 2014 tv <tv> 0.9.10.0-3.mga5
+ Revision: 668947
- rebuild for new ppp

* Fri Jul 04 2014 ovitters <ovitters> 0.9.10.0-2.mga5
+ Revision: 643113
- update url

* Fri Jul 04 2014 ovitters <ovitters> 0.9.10.0-1.mga5
+ Revision: 643103
- new version 0.9.10.0

* Wed Jun 25 2014 ovitters <ovitters> 0.9.9.98-2.mga5
+ Revision: 639657
- disable use of --no-undefined as per advice upstream (bgo#732177)

* Wed Jun 25 2014 ovitters <ovitters> 0.9.9.98-1.mga5
+ Revision: 639519
- add patch to fix linking
- new version 0.9.9.98
+ dams <dams>
- new version 0.9.8.9

* Tue Feb 11 2014 tv <tv> 0.9.9.0-0.1.mga5
+ Revision: 589409
- adjust file list
- adjust file list
- use system libndp
- new snapshot for gnome-3.11
- rediff patch 10
- drop merged patch 22

* Fri Feb 07 2014 doktor5000 <doktor5000> 0.9.8.8-4.mga5
+ Revision: 585149
- add upstream patch to not ping ModemManager every 2 minutes (mga#11725)

* Tue Jan 28 2014 colin <colin> 0.9.8.8-3.mga4
+ Revision: 568525
- Do not enable by default to allow use of draknetcenter OOTB but easy enabling if wanted

* Mon Oct 21 2013 umeabot <umeabot> 0.9.8.8-2.mga4
+ Revision: 541001
- Mageia 4 Mass Rebuild

* Thu Oct 10 2013 ovitters <ovitters> 0.9.8.8-1.mga4
+ Revision: 494818
- new version 0.9.8.8

* Mon Sep 30 2013 ovitters <ovitters> 0.9.8.6-1.mga4
+ Revision: 489620
- new version 0.9.8.6

* Wed Sep 18 2013 wally <wally> 0.9.8.4-3.mga4
+ Revision: 481301
- use pkgconfig() style require for dep added in previous release

* Wed Sep 18 2013 wally <wally> 0.9.8.4-2.mga4
+ Revision: 481291
- make libnm-glib-devel to require libnm-glib-vpn-devel

* Fri Sep 13 2013 ovitters <ovitters> 0.9.8.4-1.mga4
+ Revision: 478589
- new version 0.9.8.4

* Fri Aug 02 2013 sander85 <sander85> 0.9.8.2-2.mga4
+ Revision: 462643
- Enable ModemManager support (mga#10898)

* Wed Jun 26 2013 dams <dams> 0.9.8.2-1.mga4
+ Revision: 446679
- clean specfile
- update %%file for 'dispatcher' service
+ ovitters <ovitters>
- new version 0.9.8.2

* Sat Feb 23 2013 tmb <tmb> 0.9.8.0-1.mga3
+ Revision: 400118
- update to 0.9.8.0 final

* Mon Jan 14 2013 colin <colin> 0.9.6.4-3.mga3
+ Revision: 386000
- Fix libexec dir
- Fix build by adjusting autoreconf call.
- Do not ship a /run/NetworkManager folder. It's not used under systemd.
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Oct 26 2012 ovitters <ovitters> 0.9.6.4-1.mga3
+ Revision: 310456
- new version 0.9.6.4

* Thu Aug 09 2012 tv <tv> 0.9.6.0-2.mga3
+ Revision: 280289
- drop sysv service

* Tue Aug 07 2012 ovitters <ovitters> 0.9.6.0-1.mga3
+ Revision: 279851
- new version 0.9.6.0

* Tue Jul 24 2012 ovitters <ovitters> 0.9.5.96-1.mga3
+ Revision: 274050
- make use of _unitdir macro
- update file list
- new version 0.9.5.96

* Fri Jun 29 2012 ovitters <ovitters> 0.9.5.95-1.mga3
+ Revision: 264901
- drop merged patches
- new version 0.9.5.95

* Mon Jun 11 2012 ovitters <ovitters> 0.9.4.0-5.mga3
+ Revision: 259822
- add upstream patch to build against recent kernels
- enable systemd for session tracking

* Sat Apr 28 2012 tmb <tmb> 0.9.4.0-4.mga2
+ Revision: 233816
- Require rpm-helper >= 0.24.8-1 for systemd support

* Mon Apr 02 2012 sander85 <sander85> 0.9.4.0-3.mga2
+ Revision: 227857
- fix 'nmcli con' (https://bugzilla.redhat.com/show_bug.cgi?id=806664)

* Mon Apr 02 2012 colin <colin> 0.9.4.0-2.mga2
+ Revision: 227845
- Fix nscd deadlock when booting under systemd (mga#4509)

* Sat Mar 24 2012 ovitters <ovitters> 0.9.4.0-1.mga2
+ Revision: 226029
- add string format patch
- new version 0.9.4.0

* Mon Mar 19 2012 tmb <tmb> 0.9.3.997-2.mga2
+ Revision: 224511
- drop merged patches (P13, P50)
- build against libnl3
+ ovitters <ovitters>
- new version 0.9.3.997
- drop merged patch

* Tue Mar 06 2012 blino <blino> 0.9.3.995-3.mga2
+ Revision: 220666
- add back "discover mac address" patch, to fix handling of
  NM_CONTROLLED=no in ifcfg file
  (incorrectly dropped by fwang in r209998)
- add back "discover mac address" patch, to fix handling of
  NM_CONTROLLED=no in ifcfg file
  (incorrectly dropped by fwang in r209998)

* Mon Mar 05 2012 mitya <mitya> 0.9.3.995-2.mga2
+ Revision: 218275
- Fix NM startup bug (GNOME #671276, Mageia #4780)

* Fri Mar 02 2012 ovitters <ovitters> 0.9.3.995-1.mga2
+ Revision: 216949
- add upstream patch to fix the build
- new version 0.9.3.995
- simplify spec

* Sat Feb 18 2012 fwang <fwang> 0.9.3.990-1.mga2
+ Revision: 210390
- update file list
- drop merged patch
- new version 0.9.3.990

* Sat Nov 12 2011 fwang <fwang> 0.9.2.0-1.mga2
+ Revision: 166885
- new version 0.9.2.0

* Wed Sep 28 2011 ovitters <ovitters> 0.9.1.90-1.mga2
+ Revision: 149940
- add BR on pkgconfig(systemd)
- new version 0.9.1.90 (to fix mga#2857)
+ mikala <mikala>
- Update tarball to final 0.9.0
- use xz tarball since it's provided upstream
- rediff patch11
- autogen.sh is not needed anymore in %%prep section
+ blino <blino>
- add Default-Stop LSB header in initscript (thanks rpmlint)
- prefer ifcfg-rh plugin over keyfile
- ifcfg-rh: read WIRELESS_ESSID from ifcfg files (else NM_CONTROLLED=no interfaces fail verify step, and are managed using keyfile plugin)
- ifcfg-rh: guess mac address if not present in ifcfg file (adapted from ifcfg-mdv plugin)

* Sun Jul 17 2011 mikala <mikala> 0.8.9997-2.mga2
+ Revision: 125291
- Enable systemd support
- Save old README.urpmi as SOURCE2 ( currently the mdv plugin is not available)
- Update README.urpmi to explain how to enable networkmanager under systemd (not done automatically)

* Fri Jul 08 2011 cjw <cjw> 0.8.9997-1.mga2
+ Revision: 120221
- not a snapshot
- put gobject introspection typelib files in separate packages
- rebuild for automatic typelib deps and provides
+ mikala <mikala>
- Remove obsolete from 2008.0
- remove the ifcfg-mdv plugin since we're not providing it currently

* Tue Jun 14 2011 dmorgan <dmorgan> 0.8.9997-0.1.1.mga2
+ Revision: 106192
- Use autogen.sh
- New version 0.8.9997

* Tue Jun 14 2011 dmorgan <dmorgan> 0.8.999-0.1.1.mga2
+ Revision: 106128
- Add gobject-introspection-devel as buildrequires
- New version 0.8.999

* Thu May 12 2011 mikala <mikala> 0.8.4.0-5.mga1
+ Revision: 97431
- Remove comgt from requires (it should be pulled by initscripts now)

* Wed May 11 2011 mikala <mikala> 0.8.4.0-4.mga1
+ Revision: 97302
- Add comgt as a requires

* Wed May 04 2011 mikala <mikala> 0.8.4.0-3.mga1
+ Revision: 94764
- netprofile module need to be +x

* Wed May 04 2011 mikala <mikala> 0.8.4.0-2.mga1
+ Revision: 94551
- Add a netprofile module :
- a user using only the keyfile plugin for example can get a benefice of netprofile

* Thu Apr 21 2011 mikala <mikala> 0.8.4.0-1.mga1
+ Revision: 89442
- Update tarball to 0.8.4
- Update Readme.urpmi

* Thu Apr 14 2011 mikala <mikala> 0.8.3.999-1.mga1
+ Revision: 85243
- Update tarball to 0.8.4 rc2
- Sync mdv patch with mandriva's one

* Wed Mar 30 2011 mikala <mikala> 0.8.2-5.mga1
+ Revision: 79020
- Add keyfile plugin by default
- Use /etc/NetworkManager/NetworkManager.conf  as default configuration file
- Remove hal as BuildRequires

* Tue Jan 25 2011 dmorgan <dmorgan> 0.8.2-4.mga1
+ Revision: 39142
- Merge mdv commit 632509
- Disable systemd for now
- imported package networkmanager


* Sun Jan 16 2011 Eugeni Dodonov <eugeni@mandriva.com> 0.8.2-4mdv2011.0
+ Revision: 631154
- Build with systemd by default.

* Sat Nov 20 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 0.8.2-3mdv2011.0
+ Revision: 599216
- update mdv patch
- require syslog, messagebus on startup/shutdown
- ifcfg-mdv ignored changed ifcfg file
- on startup all connections after first unmanaged interface were
  ignored (likely present in ifcfg-rh as well)

* Tue Nov 16 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 0.8.2-2mdv2011.0
+ Revision: 598014
- patch1: merge into ifcfg-mdv changes in ifcfg-rh since initial fork

* Fri Nov 05 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 0.8.2-1mdv2011.0
+ Revision: 593780
- 0.8.2 final

* Thu Nov 04 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 0.8.1.999-1mdv2011.0
+ Revision: 593120
- update to 0.8.2-rc
  remove patch3 (upstream)
  redo patch2 (source file is moved)
  redo patch1 (ifcfg-mdv)
  conditional systemd support build, currently disabled

  + Funda Wang <fwang@mandriva.org>
    - new verison 0.8.1

* Sat Jul 17 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 0.8.0.999-1mdv2011.0
+ Revision: 554744
- update patch0 (mdv patch)
- patch3: printf format fix
- update to 0.8.1-rc

* Mon Mar 01 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 0.8-3mdv2010.1
+ Revision: 513074
- update patch1 - support WPA2/EAP wireless security; no wireless.d yet

* Fri Feb 26 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 0.8-2mdv2010.1
+ Revision: 511440
- rebuild due to stuck package
- update patch0 - support for editing system connections (wired, WEP and WPA-PSK for now)
- new version

* Thu Feb 18 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 0.7.999-4mdv2010.1
+ Revision: 507449
- add README.urpmi
- update patch1
  add comment to spec to decsribe GIT usage and commit used to generate patch
- mark nm-system-settings.conf as %%config(noreplace)
- install directory for keyfile system-settings plugin

* Sun Feb 14 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 0.7.999-3mdv2010.1
+ Revision: 505900
- patch1: really add ifcfg-mdv and set it as default

* Mon Feb 08 2010 Juan Luis Baptiste <juancho@mandriva.org> 0.7.999-2mdv2010.1
+ Revision: 502447
- Forgot to increase mkrel
- rebuild
- Added experimental patch from Eugeni to add support for a Mandriva backend.

  + Frederik Himpe <fhimpe@mandriva.org>
    - Fix summary and provides of libnm-glib-vpn-devel

* Fri Jan 22 2010 Frederik Himpe <fhimpe@mandriva.org> 0.7.999-1mdv2010.1
+ Revision: 495115
- Update to new version 0.7.999

* Fri Jan 01 2010 Frederik Himpe <fhimpe@mandriva.org> 0.7.996-0.git20100101.1mdv2010.1
+ Revision: 484900
- Update to new snapshot, build for new ppp

* Tue Nov 17 2009 Frederik Himpe <fhimpe@mandriva.org> 0.7.996-0.git20091117.1mdv2010.1
+ Revision: 467052
- Update to new git snapshot
- Remove two patches integrated upstream

* Sun Nov 15 2009 Frederik Himpe <fhimpe@mandriva.org> 0.7.996-0.git20091021.4mdv2010.1
+ Revision: 466263
- Add patch to make it use /var/lib/dhcp for the dhclient lease files

* Thu Nov 12 2009 Frederik Himpe <fhimpe@mandriva.org> 0.7.996-0.git20091021.3mdv2010.1
+ Revision: 465515
- Fix libnm-glib-vpn-devel provides

* Thu Nov 12 2009 Frederik Himpe <fhimpe@mandriva.org> 0.7.996-0.git20091021.2mdv2010.1
+ Revision: 465473
- Fix upgrade from previous versions

* Thu Nov 12 2009 Frederik Himpe <fhimpe@mandriva.org> 0.7.996-0.git20091021.1mdv2010.1
+ Revision: 465463
- Fix Requires and BuildRequires
- Sync with Fedora 12:
  * Use new 07.996 snapshot
  * Add 2 Fedora patches
  * New Requires
- Underscores in library names have been replaces by dashes
- move libnm-glib-vpn to separate subpackage because it has a
  different major now
- Install nm-system-settings.conf to the default location, in order
  to not having to patch networkmanager
- Fix libnm-util libification by moving nm-ppd-plugin.so to
  networkmanager package

* Tue Aug 04 2009 Eugeni Dodonov <eugeni@mandriva.com> 0.7.1-3mdv2010.0
+ Revision: 409343
- Updated buildrequires for libuuid.

* Tue Jun 09 2009 Eugeni Dodonov <eugeni@mandriva.com> 0.7.1-2mdv2010.0
+ Revision: 384191
- Updated to 0.7.1

* Mon Mar 30 2009 Jérôme Soyer <saispo@mandriva.org> 0.7.0.99-2mdv2009.1
+ Revision: 362254
- Fix bug 46945
- Fix bug 46945

* Fri Mar 06 2009 Jérôme Soyer <saispo@mandriva.org> 0.7.0.99-1mdv2009.1
+ Revision: 349737
- New upstream release

* Mon Dec 01 2008 Funda Wang <fwang@mandriva.org> 0.7.0-3mdv2009.1
+ Revision: 308692
- really fix bug#46095

* Sun Nov 30 2008 Funda Wang <fwang@mandriva.org> 0.7.0-2mdv2009.1
+ Revision: 308479
- add more virtaul provides
- with-mdns-provider not recognized

* Sun Nov 30 2008 Funda Wang <fwang@mandriva.org> 0.7.0-1mdv2009.1
+ Revision: 308360
- 0.7.0 final

* Wed Jul 23 2008 Götz Waschk <waschk@mandriva.org> 0.7.0-0.3675.3mdv2009.0
+ Revision: 242459
- remove comment as well
- move autoreconf call to prep stage
- fix deps exceptions for 64 bit
- remove unused configure options
- update build deps

* Wed Jul 23 2008 Götz Waschk <waschk@mandriva.org> 0.7.0-0.3675.2mdv2009.0
+ Revision: 242329
- add missing deps

* Wed Jun 18 2008 Helio Chissini de Castro <helio@mandriva.com> 0.7.0-0.3675.1mdv2009.0
+ Revision: 225776
- Changed a little bit the versionin scheme to enable use subversioning.
- Added the devel requires exceptions to allows installation of devel packages

* Tue Jun 10 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 0.7.0-0.5.svn3675mdv2009.0
+ Revision: 217721
- add buildroot
- revert previous changes that broke a lot of stuff
  * some cleanups and updating..

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers
    - adapt to %%_localstatedir now being /var instead of /var/lib (#22312)

* Mon May 19 2008 David Walluck <walluck@mandriva.org> 1:0.7.0-0.9.3.svn3669.2mdv2009.0
+ Revision: 209082
- fix typo in Obsoletes tags

* Mon May 19 2008 David Walluck <walluck@mandriva.org> 1:0.7.0-0.9.3.svn3669.1mdv2009.0
+ Revision: 208864
- enable epoch
- sync with 0.7.0-0.9.3.svn3669.fc10
- change lib package names to match library names

* Tue Mar 18 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 0.7.0-0.4mdv2008.1
+ Revision: 188564
- d'oh, remove dhcdb from buildrequires
- new svn snapshot
- update mandriva backend (P2)
- build fedora nm-system-settings plugin
- enable avahi for mdns (fixes crash with NetworkManager due to no mdns)
- this release actually works :p

* Sat Mar 01 2008 Olivier Blin <oblin@mandriva.com> 0.7.0-0.3mdv2008.1
+ Revision: 177393
- obsolete dhcdbd (obsoleted by NM >= 0.7.0)

  + Thierry Vignaud <tv@mandriva.org>
    - fix no-buildroot-tag

* Fri Feb 08 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 0.7.0-0.2mdv2008.1
+ Revision: 164291
- fix problems with conflicts of -devel packages reported by blino

* Thu Feb 07 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 0.7.0-0.1mdv2008.1
+ Revision: 163655
- fix buildrequires
- New release: 0.7.0'ish (from svn, grabbed from suse)
- sync patches (P0 & P1) and much of structure with Fedora
- add Mandriva backend (P2)
- split out nm-applet
- cleanups

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request


* Fri Feb 16 2007 Olivier Thauvin <nanardon@mandriva.org> 0.6.4-5mdv2007.0
+ Revision: 121928
- fix buildrequires
- patch2 fix compil with latest dbus

* Fri Sep 08 2006 Nicolas Lécureuil <neoclust@mandriva.org> 0.6.4-4mdv2007.0
- Add BuildRequire

* Sat Aug 05 2006 Olivier Blin <blino@mandriva.com> 0.6.4-3mdv2007.0
- Patch1: fix build for new dbus
- add libiw-devel BuildRequires and wireless-tools Requires

* Thu Jul 20 2006 Olivier Blin <blino@mandriva.com> 0.6.4-2mdv2007.0
- update icon cache

* Wed Jul 19 2006 Olivier Blin <blino@mandriva.com> 0.6.4-1mdv2007.0
- initial Mandriva release
- Patch0: fake include of <linux/if.h>

